@@ -1,7 +1,7 @@
 /**********************************************************************
  *  mainwindow.cpp
  **********************************************************************
- * Copyright (C) 2015  Authors
+ * Copyright (C) 2015 MX Authors
  *
  * Authors: Adrian
  *          MX Linux <http://mxlinux.org>
@@ -89,7 +89,7 @@ void MainWindow::loadSettings()
     mksq_opt = settings.value("mksq_opt", "-comp xz").toString();
     edit_boot_menu = settings.value("edit_boot_menu", "no").toString();
     lib_mod_dir = settings.value("lib_mod_dir", "/lib/modules/").toString();
-    gui_editor.setFileName(settings.value("gui_editor", "/usr/bin/gnome-text-editor").toString());
+    gui_editor.setFileName(settings.value("gui_editor", "/usr/bin/leafpad").toString());
     stamp = settings.value("stamp").toString();
     force_installer = settings.value("force_installer", "true").toBool();
     ui->lineEditName->setText(getFilename());
@@ -315,7 +315,7 @@ void MainWindow::copyNewIso()
     QString cmd = "tar xf /usr/lib/iso-template/iso-template.tar.gz";
     shell->run(cmd);
 
-    cmd = "cp /usr/lib/iso-template/template-initrd.gz iso-template/antiX/initrd.gz";
+    cmd = "cp /usr/lib/iso-template/initrd.gz iso-template/antiX/";
     shell->run(cmd);
 
     cmd = "cp /boot/vmlinuz-" + kernel_used + " iso-template/antiX/vmlinuz";
@@ -361,7 +361,7 @@ void MainWindow::replaceMenuStrings() {
     QString code_name = shell->getOutput("lsb_release -cs");
     QString options = "quiet";
 
-    if (debian_version < 9) { // Only for versions older than Stretch which uses old =antix-iso-template
+    if (debian_version < 9) { // Only for versions older than Stretch which uses old mx-iso-template
         if (i686) {
             QString new_string = "antiX Linux 386 (" + date + ")";
             replaceStringInFile("custom-name", new_string, work_dir + "/iso-template/boot/grub/grub.cfg");
@@ -374,7 +374,7 @@ void MainWindow::replaceMenuStrings() {
             replaceStringInFile("custom-name", new_string, work_dir + "/iso-template/boot/isolinux/isolinux.cfg");
         }
 
-    } else { // with new antix-iso-template for antiX-17 and greater
+    } else { // with new iso-template for antiX-17 and greater
         replaceStringInFile("%DISTRO_NAME%", distro_name, work_dir + "/iso-template/boot/grub/grub.cfg");
 
         replaceStringInFile("%OPTIONS%", options, work_dir + "/iso-template/boot/syslinux/syslinux.cfg");
@@ -408,8 +408,8 @@ void MainWindow::copyModules(QString to, QString kernel)
     QString cmd = QString("/usr/share/packageinstaller/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel);
     shell->run(cmd);
     // copy 586 modules for the non-PAE kernel
-    if (i686 && debian_version < 9) {  // Not applicable for Stretch (antiX-17) or more
-        QString cmd = QString("/usr/share/packageinstaller/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel586);
+    if (i686 && debian_version < 9) {  // Not applicable for Stretch (MX17) or more
+        QString cmd = QString("/usr/share/mx-packageinstaller/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel586);
         shell->run(cmd);
     }
     cmd = QString("/usr/share/packageinstaller/scripts/copy-initrd-programs --to=\"%1\"").arg(to);
@@ -516,12 +516,11 @@ void MainWindow::setupEnv()
     if (reset_accounts) {
         shell->run("installed-to-live -b /.bind-root start " + bind_boot + "empty=/home general version-file read-only");
     } else {
-        if (force_installer == true) {  // copy minstall.desktop to Desktop on all accounts
-            shell->run("echo /home/*/Desktop | xargs -n1 cp /usr/share/applications/minstall.desktop 2>/dev/null");
-            shell->run("chmod +x /home/*/Desktop/minstall.desktop");
-        }
+        // copy antixsources.desktop to Desktop on all accounts
+        system("echo /home/*/Desktop | xargs -n1 cp /usr/share/applications/antix/antixsources.desktop 2>/dev/null");
+        system("chmod +x /home/*/Desktop/antixsources.desktop");
         shell->run("installed-to-live -b /.bind-root start bind=/home" + bind_boot_too + " live-files version-file adjtime read-only");
-    }
+        }
 }
 
 int MainWindow::getDebianVersion()
